# `timestep`

Timestep AI CLI

**Usage**:

```console
$ timestep [OPTIONS] COMMAND [ARGS]...
```

**Options**:

* `--install-completion`: Install completion for the current shell.
* `--show-completion`: Show completion for the current shell, to copy it or customize the installation.
* `--help`: Show this message and exit.

**Commands**:

* `up`: Up

## `timestep up`

Up

**Usage**:

```console
$ timestep up [OPTIONS]
```

**Options**:

* `--help`: Show this message and exit.
